#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="client_message_api.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

from AsposeEmailCloudSdk.api.api_base import ApiBase
from AsposeEmailCloudSdk.models import *


class ClientMessageApi(ApiBase):
    """
    Aspose.Email Cloud API. ClientMessageApi operations.

    """

    def __init__(self, api_client):
        super(ClientMessageApi, self).__init__(api_client)

    def append(self, request: ClientMessageAppendRequest) -> ValueTOfString:
        """Add email message to specified folder in email account.             

        :param request: Append email request.
        :type request: ClientMessageAppendRequest
        :return: ValueTOfString
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `append`")

        collection_formats = {}
        path = '/email/client/message/append'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'POST', 'ValueTOfString')

    def append_file(self, request: ClientMessageAppendFileRequest) -> ValueTOfString:
        """Add email message from file to specified folder in email account.             


        :param request: ClientMessageAppendFileRequest object with parameters
        :type request: ClientMessageAppendFileRequest
        :return: ValueTOfString
        """
        # verify the required parameter 'account' is set
        if request.account is None:
            raise ValueError("Missing the required parameter `account` when calling `append_file`")
        # verify the required parameter 'file' is set
        if request.file is None:
            raise ValueError("Missing the required parameter `file` when calling `append_file`")

        collection_formats = {}
        path = '/email/client/message/file/append'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('account') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account if request.account is not None else '')
        else:
            if request.account is not None:
                query_params.append((self._lowercase_first_letter('account'), request.account))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))
        path_parameter = '{' + self._lowercase_first_letter('accountStorageFolder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account_storage_folder if request.account_storage_folder is not None else '')
        else:
            if request.account_storage_folder is not None:
                query_params.append((self._lowercase_first_letter('accountStorageFolder'), request.account_storage_folder))
        path_parameter = '{' + self._lowercase_first_letter('format') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.format if request.format is not None else '')
        else:
            if request.format is not None:
                query_params.append((self._lowercase_first_letter('format'), request.format))
        path_parameter = '{' + self._lowercase_first_letter('folder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.folder if request.folder is not None else '')
        else:
            if request.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), request.folder))
        path_parameter = '{' + self._lowercase_first_letter('markAsSent') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.mark_as_sent if request.mark_as_sent is not None else '')
        else:
            if request.mark_as_sent is not None:
                query_params.append((self._lowercase_first_letter('markAsSent'), request.mark_as_sent))

        form_params = []
        local_var_files = []
        if request.file is not None:
            local_var_files.append((self._lowercase_first_letter('File'), request.file))

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['multipart/form-data'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'POST', 'ValueTOfString')

    def delete(self, request: ClientMessageDeleteRequest):
        """Delete message.             

        :param request: Delete message request.
        :type request: ClientMessageDeleteRequest
        :return: None
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `delete`")

        collection_formats = {}
        path = '/email/client/message'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'DELETE', None)

    def fetch(self, request: ClientMessageFetchRequest) -> MailMessageBase:
        """Fetch message from email account             


        :param request: ClientMessageFetchRequest object with parameters
        :type request: ClientMessageFetchRequest
        :return: MailMessageBase
        """
        # verify the required parameter 'message_id' is set
        if request.message_id is None:
            raise ValueError("Missing the required parameter `message_id` when calling `fetch`")
        # verify the required parameter 'account' is set
        if request.account is None:
            raise ValueError("Missing the required parameter `account` when calling `fetch`")

        collection_formats = {}
        path = '/email/client/message'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('messageId') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.message_id if request.message_id is not None else '')
        else:
            if request.message_id is not None:
                query_params.append((self._lowercase_first_letter('messageId'), request.message_id))
        path_parameter = '{' + self._lowercase_first_letter('account') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account if request.account is not None else '')
        else:
            if request.account is not None:
                query_params.append((self._lowercase_first_letter('account'), request.account))
        path_parameter = '{' + self._lowercase_first_letter('folder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.folder if request.folder is not None else '')
        else:
            if request.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), request.folder))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))
        path_parameter = '{' + self._lowercase_first_letter('accountStorageFolder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account_storage_folder if request.account_storage_folder is not None else '')
        else:
            if request.account_storage_folder is not None:
                query_params.append((self._lowercase_first_letter('accountStorageFolder'), request.account_storage_folder))
        path_parameter = '{' + self._lowercase_first_letter('type') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.type if request.type is not None else '')
        else:
            if request.type is not None:
                query_params.append((self._lowercase_first_letter('type'), request.type))
        path_parameter = '{' + self._lowercase_first_letter('format') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.format if request.format is not None else '')
        else:
            if request.format is not None:
                query_params.append((self._lowercase_first_letter('format'), request.format))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'GET', 'MailMessageBase')

    def fetch_file(self, request: ClientMessageFetchFileRequest) -> str:
        """Fetch message as file from email account             


        :param request: ClientMessageFetchFileRequest object with parameters
        :type request: ClientMessageFetchFileRequest
        :return: str
        """
        # verify the required parameter 'message_id' is set
        if request.message_id is None:
            raise ValueError("Missing the required parameter `message_id` when calling `fetch_file`")
        # verify the required parameter 'account' is set
        if request.account is None:
            raise ValueError("Missing the required parameter `account` when calling `fetch_file`")

        collection_formats = {}
        path = '/email/client/message/file'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('messageId') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.message_id if request.message_id is not None else '')
        else:
            if request.message_id is not None:
                query_params.append((self._lowercase_first_letter('messageId'), request.message_id))
        path_parameter = '{' + self._lowercase_first_letter('account') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account if request.account is not None else '')
        else:
            if request.account is not None:
                query_params.append((self._lowercase_first_letter('account'), request.account))
        path_parameter = '{' + self._lowercase_first_letter('folder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.folder if request.folder is not None else '')
        else:
            if request.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), request.folder))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))
        path_parameter = '{' + self._lowercase_first_letter('accountStorageFolder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account_storage_folder if request.account_storage_folder is not None else '')
        else:
            if request.account_storage_folder is not None:
                query_params.append((self._lowercase_first_letter('accountStorageFolder'), request.account_storage_folder))
        path_parameter = '{' + self._lowercase_first_letter('format') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.format if request.format is not None else '')
        else:
            if request.format is not None:
                query_params.append((self._lowercase_first_letter('format'), request.format))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['multipart/form-data'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'GET', 'file')

    def list(self, request: ClientMessageListRequest) -> MailMessageBaseList:
        """Get messages from folder, filtered by query             

        The query string should have the following view.      The example of a simple expression:       '<Field name>' <Comparison operator> '<Field value>',  where &lt;Field Name&gt; - the name of a message field through which filtering is made, &lt;Comparison operator&gt; - comparison operators, as their name implies, allow to compare message field and specified value, &lt;Field value&gt; - value to be compared with a message field.      The number of simple expressions can make a compound one, ex.:     (<Simple expression 1> & <Simple expression 2>) | <Simple expression 3     >,  where \"&amp;\" - logical-AND operator, \"|\" - logical-OR operator      At present the following values are allowed as a field name (<Field name>):  \"To\" - represents a TO field of message, \"Text\" - represents string in the header or body of the message, \"Bcc\" - represents a BCC field of message, \"Body\" - represents a string in the body of message, \"Cc\" - represents a CC field of message, \"From\" - represents a From field of message, \"Subject\" - represents a string in the subject of message, \"InternalDate\" - represents an internal date of message, \"SentDate\" - represents a sent date of message      Additionally, the following field names are allowed for IMAP-protocol:  \"Answered\" - represents an /Answered flag of message \"Seen\" - represents a /Seen flag of message \"Flagged\" - represents a /Flagged flag of message \"Draft\" - represents a /Draft flag of message \"Deleted\" - represents a Deleted/ flag of message \"Recent\" - represents a Deleted/ flag of message \"MessageSize\" - represents a size (in bytes) of message      Additionally, the following field names are allowed for Exchange:  \"IsRead\" - Indicates whether the message has been read \"HasAttachment\" - Indicates whether or not the message has attachments \"IsSubmitted\" - Indicates whether the message has been submitted to the Outbox \"ContentClass\" - represents a content class of item      The field value (<Field value>) can take the following values:     For text fields - any string,     For date type fields - the string of \"d-MMM-yyy\" format, ex. \"10-Feb-2009\",     For flags (fields of boolean type) - either \"True\", or \"False\"              

        :param request: ClientMessageListRequest object with parameters
        :type request: ClientMessageListRequest
        :return: MailMessageBaseList
        """
        # verify the required parameter 'folder' is set
        if request.folder is None:
            raise ValueError("Missing the required parameter `folder` when calling `list`")
        # verify the required parameter 'account' is set
        if request.account is None:
            raise ValueError("Missing the required parameter `account` when calling `list`")

        collection_formats = {}
        path = '/email/client/message/list'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('folder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.folder if request.folder is not None else '')
        else:
            if request.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), request.folder))
        path_parameter = '{' + self._lowercase_first_letter('account') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account if request.account is not None else '')
        else:
            if request.account is not None:
                query_params.append((self._lowercase_first_letter('account'), request.account))
        path_parameter = '{' + self._lowercase_first_letter('queryString') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.query_string if request.query_string is not None else '')
        else:
            if request.query_string is not None:
                query_params.append((self._lowercase_first_letter('queryString'), request.query_string))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))
        path_parameter = '{' + self._lowercase_first_letter('accountStorageFolder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account_storage_folder if request.account_storage_folder is not None else '')
        else:
            if request.account_storage_folder is not None:
                query_params.append((self._lowercase_first_letter('accountStorageFolder'), request.account_storage_folder))
        path_parameter = '{' + self._lowercase_first_letter('recursive') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.recursive if request.recursive is not None else '')
        else:
            if request.recursive is not None:
                query_params.append((self._lowercase_first_letter('recursive'), request.recursive))
        path_parameter = '{' + self._lowercase_first_letter('type') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.type if request.type is not None else '')
        else:
            if request.type is not None:
                query_params.append((self._lowercase_first_letter('type'), request.type))
        path_parameter = '{' + self._lowercase_first_letter('format') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.format if request.format is not None else '')
        else:
            if request.format is not None:
                query_params.append((self._lowercase_first_letter('format'), request.format))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'GET', 'MailMessageBaseList')

    def move(self, request: ClientMessageMoveRequest):
        """Move message to another folder.             

        :param request: Move message request.
        :type request: ClientMessageMoveRequest
        :return: None
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `move`")

        collection_formats = {}
        path = '/email/client/message/move'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'PUT', None)

    def send(self, request: ClientMessageSendRequest):
        """Send an email specified by model in request.             

        :param request: Send email request.
        :type request: ClientMessageSendRequest
        :return: None
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `send`")

        collection_formats = {}
        path = '/email/client/message'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'POST', None)

    def send_file(self, request: ClientMessageSendFileRequest):
        """Send an email file.             


        :param request: ClientMessageSendFileRequest object with parameters
        :type request: ClientMessageSendFileRequest
        :return: None
        """
        # verify the required parameter 'account' is set
        if request.account is None:
            raise ValueError("Missing the required parameter `account` when calling `send_file`")
        # verify the required parameter 'file' is set
        if request.file is None:
            raise ValueError("Missing the required parameter `file` when calling `send_file`")

        collection_formats = {}
        path = '/email/client/message/file'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('account') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account if request.account is not None else '')
        else:
            if request.account is not None:
                query_params.append((self._lowercase_first_letter('account'), request.account))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))
        path_parameter = '{' + self._lowercase_first_letter('accountStorageFolder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account_storage_folder if request.account_storage_folder is not None else '')
        else:
            if request.account_storage_folder is not None:
                query_params.append((self._lowercase_first_letter('accountStorageFolder'), request.account_storage_folder))
        path_parameter = '{' + self._lowercase_first_letter('format') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.format if request.format is not None else '')
        else:
            if request.format is not None:
                query_params.append((self._lowercase_first_letter('format'), request.format))

        form_params = []
        local_var_files = []
        if request.file is not None:
            local_var_files.append((self._lowercase_first_letter('File'), request.file))

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['multipart/form-data'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'POST', None)

    def set_is_read(self, request: ClientMessageSetIsReadRequest):
        """Mark message as read or unread.             

        :param request: Delete message request.
        :type request: ClientMessageSetIsReadRequest
        :return: None
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `set_is_read`")

        collection_formats = {}
        path = '/email/client/message/set-is-read'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'PUT', None)




#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiContactProfessionalPropertySetDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime


class MapiContactProfessionalPropertySetDto(object):
    """Properties are used to store professional details for the person represented by the contact             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'title': 'str',
        'company_name': 'str',
        'department_name': 'str',
        'office_location': 'str',
        'manager_name': 'str',
        'assistant': 'str',
        'profession': 'str'
    }

    attribute_map = {
        'title': 'title',
        'company_name': 'companyName',
        'department_name': 'departmentName',
        'office_location': 'officeLocation',
        'manager_name': 'managerName',
        'assistant': 'assistant',
        'profession': 'profession'
    }

    def __init__(self, title: str = None, company_name: str = None, department_name: str = None, office_location: str = None, manager_name: str = None, assistant: str = None, profession: str = None):
        """
        Properties are used to store professional details for the person represented by the contact             
        :param title: Gets or sets the job title of the contact             
        :type title: str
        :param company_name: Gets or sets the company that employs the contact             
        :type company_name: str
        :param department_name: Gets or sets the name of the department to which the contact belongs             
        :type department_name: str
        :param office_location: Gets or sets the location of the office that the contact works in             
        :type office_location: str
        :param manager_name: Gets or sets the name of the contact's manager             
        :type manager_name: str
        :param assistant: Gets or sets the name of the contact's assistant             
        :type assistant: str
        :param profession: Gets or sets the profession of the contact             
        :type profession: str
        """

        self._title = None
        self._company_name = None
        self._department_name = None
        self._office_location = None
        self._manager_name = None
        self._assistant = None
        self._profession = None

        if title is not None:
            self.title = title
        if company_name is not None:
            self.company_name = company_name
        if department_name is not None:
            self.department_name = department_name
        if office_location is not None:
            self.office_location = office_location
        if manager_name is not None:
            self.manager_name = manager_name
        if assistant is not None:
            self.assistant = assistant
        if profession is not None:
            self.profession = profession


    @property
    def title(self) -> str:
        """
        Gets or sets the job title of the contact             

        :return: The title of this MapiContactProfessionalPropertySetDto.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title: str):
        """
        Gets or sets the job title of the contact             

        :param title: The title of this MapiContactProfessionalPropertySetDto.
        :type: str
        """
        self._title = title

    @property
    def company_name(self) -> str:
        """
        Gets or sets the company that employs the contact             

        :return: The company_name of this MapiContactProfessionalPropertySetDto.
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name: str):
        """
        Gets or sets the company that employs the contact             

        :param company_name: The company_name of this MapiContactProfessionalPropertySetDto.
        :type: str
        """
        self._company_name = company_name

    @property
    def department_name(self) -> str:
        """
        Gets or sets the name of the department to which the contact belongs             

        :return: The department_name of this MapiContactProfessionalPropertySetDto.
        :rtype: str
        """
        return self._department_name

    @department_name.setter
    def department_name(self, department_name: str):
        """
        Gets or sets the name of the department to which the contact belongs             

        :param department_name: The department_name of this MapiContactProfessionalPropertySetDto.
        :type: str
        """
        self._department_name = department_name

    @property
    def office_location(self) -> str:
        """
        Gets or sets the location of the office that the contact works in             

        :return: The office_location of this MapiContactProfessionalPropertySetDto.
        :rtype: str
        """
        return self._office_location

    @office_location.setter
    def office_location(self, office_location: str):
        """
        Gets or sets the location of the office that the contact works in             

        :param office_location: The office_location of this MapiContactProfessionalPropertySetDto.
        :type: str
        """
        self._office_location = office_location

    @property
    def manager_name(self) -> str:
        """
        Gets or sets the name of the contact's manager             

        :return: The manager_name of this MapiContactProfessionalPropertySetDto.
        :rtype: str
        """
        return self._manager_name

    @manager_name.setter
    def manager_name(self, manager_name: str):
        """
        Gets or sets the name of the contact's manager             

        :param manager_name: The manager_name of this MapiContactProfessionalPropertySetDto.
        :type: str
        """
        self._manager_name = manager_name

    @property
    def assistant(self) -> str:
        """
        Gets or sets the name of the contact's assistant             

        :return: The assistant of this MapiContactProfessionalPropertySetDto.
        :rtype: str
        """
        return self._assistant

    @assistant.setter
    def assistant(self, assistant: str):
        """
        Gets or sets the name of the contact's assistant             

        :param assistant: The assistant of this MapiContactProfessionalPropertySetDto.
        :type: str
        """
        self._assistant = assistant

    @property
    def profession(self) -> str:
        """
        Gets or sets the profession of the contact             

        :return: The profession of this MapiContactProfessionalPropertySetDto.
        :rtype: str
        """
        return self._profession

    @profession.setter
    def profession(self, profession: str):
        """
        Gets or sets the profession of the contact             

        :param profession: The profession of this MapiContactProfessionalPropertySetDto.
        :type: str
        """
        self._profession = profession

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiContactProfessionalPropertySetDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="ClientMessageAppendRequest.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.client_account_base_request import ClientAccountBaseRequest
from AsposeEmailCloudSdk.models.mail_message_base import MailMessageBase
from AsposeEmailCloudSdk.models.storage_file_location import StorageFileLocation


class ClientMessageAppendRequest(ClientAccountBaseRequest):
    """Email client append message request.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_location': 'StorageFileLocation',
        'folder': 'str',
        'message': 'MailMessageBase',
        'mark_as_sent': 'bool'
    }

    attribute_map = {
        'account_location': 'accountLocation',
        'folder': 'folder',
        'message': 'message',
        'mark_as_sent': 'markAsSent'
    }

    def __init__(self, account_location: StorageFileLocation = None, folder: str = None, message: MailMessageBase = None, mark_as_sent: bool = None):
        """
        Email client append message request.             
        :param account_location: Email client account configuration location on storage.             
        :type account_location: StorageFileLocation
        :param folder: Path to folder on email server to append message to.             
        :type folder: str
        :param message: Message to append.             
        :type message: MailMessageBase
        :param mark_as_sent: Determines that appended message should be market as sent or not.             
        :type mark_as_sent: bool
        """
        super(ClientMessageAppendRequest, self).__init__()

        self._folder = None
        self._message = None
        self._mark_as_sent = None

        if account_location is not None:
            self.account_location = account_location
        if folder is not None:
            self.folder = folder
        if message is not None:
            self.message = message
        if mark_as_sent is not None:
            self.mark_as_sent = mark_as_sent


    @property
    def folder(self) -> str:
        """
        Path to folder on email server to append message to.             

        :return: The folder of this ClientMessageAppendRequest.
        :rtype: str
        """
        return self._folder

    @folder.setter
    def folder(self, folder: str):
        """
        Path to folder on email server to append message to.             

        :param folder: The folder of this ClientMessageAppendRequest.
        :type: str
        """
        self._folder = folder

    @property
    def message(self) -> MailMessageBase:
        """
        Message to append.             

        :return: The message of this ClientMessageAppendRequest.
        :rtype: MailMessageBase
        """
        return self._message

    @message.setter
    def message(self, message: MailMessageBase):
        """
        Message to append.             

        :param message: The message of this ClientMessageAppendRequest.
        :type: MailMessageBase
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")
        self._message = message

    @property
    def mark_as_sent(self) -> bool:
        """
        Determines that appended message should be market as sent or not.             

        :return: The mark_as_sent of this ClientMessageAppendRequest.
        :rtype: bool
        """
        return self._mark_as_sent

    @mark_as_sent.setter
    def mark_as_sent(self, mark_as_sent: bool):
        """
        Determines that appended message should be market as sent or not.             

        :param mark_as_sent: The mark_as_sent of this ClientMessageAppendRequest.
        :type: bool
        """
        if mark_as_sent is None:
            raise ValueError("Invalid value for `mark_as_sent`, must not be `None`")
        self._mark_as_sent = mark_as_sent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClientMessageAppendRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="client_message_fetch_request.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from AsposeEmailCloudSdk.models import *


class ClientMessageFetchRequest(object):
    """
    Request model for client_message_fetch operation.
    Initializes a new instance.

    :param message_id: Message identifier
    :type message_id: str
    :param account: Email account
    :type account: str
    :param folder: Account folder to fetch from (should be specified for some protocols such as IMAP)             
    :type folder: str
    :param storage: Storage name where account file located.
    :type storage: str
    :param account_storage_folder: Folder in storage where account file located.
    :type account_storage_folder: str
    :param type: MailMessageBase type. Using this property you can fetch message in different formats (as EmailDto, MapiMessageDto or a file represented as Base64 string).              Enum, available values: Dto, Mapi, Base64
    :type type: str
    :param format: Base64 data format. Used only if type is set to Base64. Enum, available values: Eml, Msg, MsgUnicode, Mhtml, Html, Tnef, Oft
    :type format: str
    """

    def __init__(self, message_id: str, account: str, folder: str = None, storage: str = None, account_storage_folder: str = None, type: str = None, format: str = None):
        """
        Request model for client_message_fetch operation.
        Initializes a new instance.

        :param message_id: Message identifier
        :type message_id: str
        :param account: Email account
        :type account: str
        :param folder: Account folder to fetch from (should be specified for some protocols such as IMAP)             
        :type folder: str
        :param storage: Storage name where account file located.
        :type storage: str
        :param account_storage_folder: Folder in storage where account file located.
        :type account_storage_folder: str
        :param type: MailMessageBase type. Using this property you can fetch message in different formats (as EmailDto, MapiMessageDto or a file represented as Base64 string).              Enum, available values: Dto, Mapi, Base64
        :type type: str
        :param format: Base64 data format. Used only if type is set to Base64. Enum, available values: Eml, Msg, MsgUnicode, Mhtml, Html, Tnef, Oft
        :type format: str
        """

        self.message_id = message_id
        self.account = account
        self.folder = folder
        self.storage = storage
        self.account_storage_folder = account_storage_folder
        self.type = type
        self.format = format



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiContactTelephonePropertySetDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime


class MapiContactTelephonePropertySetDto(object):
    """Specify optional telephone numbers for the contact.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_empty': 'bool',
        'default_telephone_number': 'str',
        'use_autocomplete': 'bool',
        'callback_telephone_number': 'str',
        'business_telephone_number': 'str',
        'home_telephone_number': 'str',
        'primary_telephone_number': 'str',
        'business2_telephone_number': 'str',
        'mobile_telephone_number': 'str',
        'radio_telephone_number': 'str',
        'car_telephone_number': 'str',
        'other_telephone_number': 'str',
        'assistant_telephone_number': 'str',
        'home2_telephone_number': 'str',
        'tty_tdd_phone_number': 'str',
        'company_main_telephone_number': 'str',
        'telex_number': 'str',
        'isdn_number': 'str',
        'pager_telephone_number': 'str'
    }

    attribute_map = {
        'is_empty': 'isEmpty',
        'default_telephone_number': 'defaultTelephoneNumber',
        'use_autocomplete': 'useAutocomplete',
        'callback_telephone_number': 'callbackTelephoneNumber',
        'business_telephone_number': 'businessTelephoneNumber',
        'home_telephone_number': 'homeTelephoneNumber',
        'primary_telephone_number': 'primaryTelephoneNumber',
        'business2_telephone_number': 'business2TelephoneNumber',
        'mobile_telephone_number': 'mobileTelephoneNumber',
        'radio_telephone_number': 'radioTelephoneNumber',
        'car_telephone_number': 'carTelephoneNumber',
        'other_telephone_number': 'otherTelephoneNumber',
        'assistant_telephone_number': 'assistantTelephoneNumber',
        'home2_telephone_number': 'home2TelephoneNumber',
        'tty_tdd_phone_number': 'ttyTddPhoneNumber',
        'company_main_telephone_number': 'companyMainTelephoneNumber',
        'telex_number': 'telexNumber',
        'isdn_number': 'isdnNumber',
        'pager_telephone_number': 'pagerTelephoneNumber'
    }

    def __init__(self, is_empty: bool = None, default_telephone_number: str = None, use_autocomplete: bool = None, callback_telephone_number: str = None, business_telephone_number: str = None, home_telephone_number: str = None, primary_telephone_number: str = None, business2_telephone_number: str = None, mobile_telephone_number: str = None, radio_telephone_number: str = None, car_telephone_number: str = None, other_telephone_number: str = None, assistant_telephone_number: str = None, home2_telephone_number: str = None, tty_tdd_phone_number: str = None, company_main_telephone_number: str = None, telex_number: str = None, isdn_number: str = None, pager_telephone_number: str = None):
        """
        Specify optional telephone numbers for the contact.             
        :param is_empty: Shows if MapiContactTelephonePropertySet is empty             
        :type is_empty: bool
        :param default_telephone_number: Default value of electronic address Uses when user does not set any electronic address if UseAutocomplete property is set 'true'             
        :type default_telephone_number: str
        :param use_autocomplete: Indicates that one electronic address is completed automatically in case if user does not set any electronic address             
        :type use_autocomplete: bool
        :param callback_telephone_number: Gets or sets the callback telephone number             
        :type callback_telephone_number: str
        :param business_telephone_number: Gets or sets the business telephone number             
        :type business_telephone_number: str
        :param home_telephone_number: Gets or sets the home telephone number             
        :type home_telephone_number: str
        :param primary_telephone_number: Gets or sets the primary telephone number             
        :type primary_telephone_number: str
        :param business2_telephone_number: Gets or sets the second business telephone number             
        :type business2_telephone_number: str
        :param mobile_telephone_number: Gets or sets the mobile telephone number             
        :type mobile_telephone_number: str
        :param radio_telephone_number: Gets or sets the radio telephone number             
        :type radio_telephone_number: str
        :param car_telephone_number: Gets or sets the car telephone number             
        :type car_telephone_number: str
        :param other_telephone_number: Gets or sets an alternate telephone number             
        :type other_telephone_number: str
        :param assistant_telephone_number: Gets or sets the telephone number of the contact's assistant             
        :type assistant_telephone_number: str
        :param home2_telephone_number: Gets or sets a second home telephone number             
        :type home2_telephone_number: str
        :param tty_tdd_phone_number: Gets or sets the telephone number for the contact's text telephone (TTY) or telecommunication device for the deaf (TDD)             
        :type tty_tdd_phone_number: str
        :param company_main_telephone_number: Gets or sets the company phone number             
        :type company_main_telephone_number: str
        :param telex_number: Gets or sets the telex number             
        :type telex_number: str
        :param isdn_number: Gets or sets the integrated services digital network (ISDN) number             
        :type isdn_number: str
        :param pager_telephone_number: Gets or sets a pager telephone number             
        :type pager_telephone_number: str
        """

        self._is_empty = None
        self._default_telephone_number = None
        self._use_autocomplete = None
        self._callback_telephone_number = None
        self._business_telephone_number = None
        self._home_telephone_number = None
        self._primary_telephone_number = None
        self._business2_telephone_number = None
        self._mobile_telephone_number = None
        self._radio_telephone_number = None
        self._car_telephone_number = None
        self._other_telephone_number = None
        self._assistant_telephone_number = None
        self._home2_telephone_number = None
        self._tty_tdd_phone_number = None
        self._company_main_telephone_number = None
        self._telex_number = None
        self._isdn_number = None
        self._pager_telephone_number = None

        if is_empty is not None:
            self.is_empty = is_empty
        if default_telephone_number is not None:
            self.default_telephone_number = default_telephone_number
        if use_autocomplete is not None:
            self.use_autocomplete = use_autocomplete
        if callback_telephone_number is not None:
            self.callback_telephone_number = callback_telephone_number
        if business_telephone_number is not None:
            self.business_telephone_number = business_telephone_number
        if home_telephone_number is not None:
            self.home_telephone_number = home_telephone_number
        if primary_telephone_number is not None:
            self.primary_telephone_number = primary_telephone_number
        if business2_telephone_number is not None:
            self.business2_telephone_number = business2_telephone_number
        if mobile_telephone_number is not None:
            self.mobile_telephone_number = mobile_telephone_number
        if radio_telephone_number is not None:
            self.radio_telephone_number = radio_telephone_number
        if car_telephone_number is not None:
            self.car_telephone_number = car_telephone_number
        if other_telephone_number is not None:
            self.other_telephone_number = other_telephone_number
        if assistant_telephone_number is not None:
            self.assistant_telephone_number = assistant_telephone_number
        if home2_telephone_number is not None:
            self.home2_telephone_number = home2_telephone_number
        if tty_tdd_phone_number is not None:
            self.tty_tdd_phone_number = tty_tdd_phone_number
        if company_main_telephone_number is not None:
            self.company_main_telephone_number = company_main_telephone_number
        if telex_number is not None:
            self.telex_number = telex_number
        if isdn_number is not None:
            self.isdn_number = isdn_number
        if pager_telephone_number is not None:
            self.pager_telephone_number = pager_telephone_number


    @property
    def is_empty(self) -> bool:
        """
        Shows if MapiContactTelephonePropertySet is empty             

        :return: The is_empty of this MapiContactTelephonePropertySetDto.
        :rtype: bool
        """
        return self._is_empty

    @is_empty.setter
    def is_empty(self, is_empty: bool):
        """
        Shows if MapiContactTelephonePropertySet is empty             

        :param is_empty: The is_empty of this MapiContactTelephonePropertySetDto.
        :type: bool
        """
        if is_empty is None:
            raise ValueError("Invalid value for `is_empty`, must not be `None`")
        self._is_empty = is_empty

    @property
    def default_telephone_number(self) -> str:
        """
        Default value of electronic address Uses when user does not set any electronic address if UseAutocomplete property is set 'true'             

        :return: The default_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._default_telephone_number

    @default_telephone_number.setter
    def default_telephone_number(self, default_telephone_number: str):
        """
        Default value of electronic address Uses when user does not set any electronic address if UseAutocomplete property is set 'true'             

        :param default_telephone_number: The default_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._default_telephone_number = default_telephone_number

    @property
    def use_autocomplete(self) -> bool:
        """
        Indicates that one electronic address is completed automatically in case if user does not set any electronic address             

        :return: The use_autocomplete of this MapiContactTelephonePropertySetDto.
        :rtype: bool
        """
        return self._use_autocomplete

    @use_autocomplete.setter
    def use_autocomplete(self, use_autocomplete: bool):
        """
        Indicates that one electronic address is completed automatically in case if user does not set any electronic address             

        :param use_autocomplete: The use_autocomplete of this MapiContactTelephonePropertySetDto.
        :type: bool
        """
        if use_autocomplete is None:
            raise ValueError("Invalid value for `use_autocomplete`, must not be `None`")
        self._use_autocomplete = use_autocomplete

    @property
    def callback_telephone_number(self) -> str:
        """
        Gets or sets the callback telephone number             

        :return: The callback_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._callback_telephone_number

    @callback_telephone_number.setter
    def callback_telephone_number(self, callback_telephone_number: str):
        """
        Gets or sets the callback telephone number             

        :param callback_telephone_number: The callback_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._callback_telephone_number = callback_telephone_number

    @property
    def business_telephone_number(self) -> str:
        """
        Gets or sets the business telephone number             

        :return: The business_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._business_telephone_number

    @business_telephone_number.setter
    def business_telephone_number(self, business_telephone_number: str):
        """
        Gets or sets the business telephone number             

        :param business_telephone_number: The business_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._business_telephone_number = business_telephone_number

    @property
    def home_telephone_number(self) -> str:
        """
        Gets or sets the home telephone number             

        :return: The home_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._home_telephone_number

    @home_telephone_number.setter
    def home_telephone_number(self, home_telephone_number: str):
        """
        Gets or sets the home telephone number             

        :param home_telephone_number: The home_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._home_telephone_number = home_telephone_number

    @property
    def primary_telephone_number(self) -> str:
        """
        Gets or sets the primary telephone number             

        :return: The primary_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._primary_telephone_number

    @primary_telephone_number.setter
    def primary_telephone_number(self, primary_telephone_number: str):
        """
        Gets or sets the primary telephone number             

        :param primary_telephone_number: The primary_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._primary_telephone_number = primary_telephone_number

    @property
    def business2_telephone_number(self) -> str:
        """
        Gets or sets the second business telephone number             

        :return: The business2_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._business2_telephone_number

    @business2_telephone_number.setter
    def business2_telephone_number(self, business2_telephone_number: str):
        """
        Gets or sets the second business telephone number             

        :param business2_telephone_number: The business2_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._business2_telephone_number = business2_telephone_number

    @property
    def mobile_telephone_number(self) -> str:
        """
        Gets or sets the mobile telephone number             

        :return: The mobile_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._mobile_telephone_number

    @mobile_telephone_number.setter
    def mobile_telephone_number(self, mobile_telephone_number: str):
        """
        Gets or sets the mobile telephone number             

        :param mobile_telephone_number: The mobile_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._mobile_telephone_number = mobile_telephone_number

    @property
    def radio_telephone_number(self) -> str:
        """
        Gets or sets the radio telephone number             

        :return: The radio_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._radio_telephone_number

    @radio_telephone_number.setter
    def radio_telephone_number(self, radio_telephone_number: str):
        """
        Gets or sets the radio telephone number             

        :param radio_telephone_number: The radio_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._radio_telephone_number = radio_telephone_number

    @property
    def car_telephone_number(self) -> str:
        """
        Gets or sets the car telephone number             

        :return: The car_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._car_telephone_number

    @car_telephone_number.setter
    def car_telephone_number(self, car_telephone_number: str):
        """
        Gets or sets the car telephone number             

        :param car_telephone_number: The car_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._car_telephone_number = car_telephone_number

    @property
    def other_telephone_number(self) -> str:
        """
        Gets or sets an alternate telephone number             

        :return: The other_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._other_telephone_number

    @other_telephone_number.setter
    def other_telephone_number(self, other_telephone_number: str):
        """
        Gets or sets an alternate telephone number             

        :param other_telephone_number: The other_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._other_telephone_number = other_telephone_number

    @property
    def assistant_telephone_number(self) -> str:
        """
        Gets or sets the telephone number of the contact's assistant             

        :return: The assistant_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._assistant_telephone_number

    @assistant_telephone_number.setter
    def assistant_telephone_number(self, assistant_telephone_number: str):
        """
        Gets or sets the telephone number of the contact's assistant             

        :param assistant_telephone_number: The assistant_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._assistant_telephone_number = assistant_telephone_number

    @property
    def home2_telephone_number(self) -> str:
        """
        Gets or sets a second home telephone number             

        :return: The home2_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._home2_telephone_number

    @home2_telephone_number.setter
    def home2_telephone_number(self, home2_telephone_number: str):
        """
        Gets or sets a second home telephone number             

        :param home2_telephone_number: The home2_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._home2_telephone_number = home2_telephone_number

    @property
    def tty_tdd_phone_number(self) -> str:
        """
        Gets or sets the telephone number for the contact's text telephone (TTY) or telecommunication device for the deaf (TDD)             

        :return: The tty_tdd_phone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._tty_tdd_phone_number

    @tty_tdd_phone_number.setter
    def tty_tdd_phone_number(self, tty_tdd_phone_number: str):
        """
        Gets or sets the telephone number for the contact's text telephone (TTY) or telecommunication device for the deaf (TDD)             

        :param tty_tdd_phone_number: The tty_tdd_phone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._tty_tdd_phone_number = tty_tdd_phone_number

    @property
    def company_main_telephone_number(self) -> str:
        """
        Gets or sets the company phone number             

        :return: The company_main_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._company_main_telephone_number

    @company_main_telephone_number.setter
    def company_main_telephone_number(self, company_main_telephone_number: str):
        """
        Gets or sets the company phone number             

        :param company_main_telephone_number: The company_main_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._company_main_telephone_number = company_main_telephone_number

    @property
    def telex_number(self) -> str:
        """
        Gets or sets the telex number             

        :return: The telex_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._telex_number

    @telex_number.setter
    def telex_number(self, telex_number: str):
        """
        Gets or sets the telex number             

        :param telex_number: The telex_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._telex_number = telex_number

    @property
    def isdn_number(self) -> str:
        """
        Gets or sets the integrated services digital network (ISDN) number             

        :return: The isdn_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._isdn_number

    @isdn_number.setter
    def isdn_number(self, isdn_number: str):
        """
        Gets or sets the integrated services digital network (ISDN) number             

        :param isdn_number: The isdn_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._isdn_number = isdn_number

    @property
    def pager_telephone_number(self) -> str:
        """
        Gets or sets a pager telephone number             

        :return: The pager_telephone_number of this MapiContactTelephonePropertySetDto.
        :rtype: str
        """
        return self._pager_telephone_number

    @pager_telephone_number.setter
    def pager_telephone_number(self, pager_telephone_number: str):
        """
        Gets or sets a pager telephone number             

        :param pager_telephone_number: The pager_telephone_number of this MapiContactTelephonePropertySetDto.
        :type: str
        """
        self._pager_telephone_number = pager_telephone_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiContactTelephonePropertySetDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiCalendarTimeZoneRuleDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime


class MapiCalendarTimeZoneRuleDto(object):
    """Represents time zone rule that indicate when to begin using the Standard/Daylight time.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_date': 'datetime',
        'day_of_week': 'str',
        'hour': 'int',
        'milliseconds': 'int',
        'minute': 'int',
        'month': 'int',
        'position': 'str',
        'seconds': 'int',
        'year': 'int'
    }

    attribute_map = {
        '_date': 'date',
        'day_of_week': 'dayOfWeek',
        'hour': 'hour',
        'milliseconds': 'milliseconds',
        'minute': 'minute',
        'month': 'month',
        'position': 'position',
        'seconds': 'seconds',
        'year': 'year'
    }

    def __init__(self, _date: datetime = None, day_of_week: str = None, hour: int = None, milliseconds: int = None, minute: int = None, month: int = None, position: str = None, seconds: int = None, year: int = None):
        """
        Represents time zone rule that indicate when to begin using the Standard/Daylight time.             
        :param _date: Date and time that indicate when to begin using the Standard/Daylight time.             
        :type _date: datetime
        :param day_of_week: Day of week. Enum, available values: Sunday, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday
        :type day_of_week: str
        :param hour: Hour.             
        :type hour: int
        :param milliseconds: Milliseconds.             
        :type milliseconds: int
        :param minute: Minute.             
        :type minute: int
        :param month: Month.             
        :type month: int
        :param position: Day positions, typically found in a month. Enum, available values: None, First, Second, Third, Fourth, Last
        :type position: str
        :param seconds: Seconds.             
        :type seconds: int
        :param year: Year.             
        :type year: int
        """

        self.__date = None
        self._day_of_week = None
        self._hour = None
        self._milliseconds = None
        self._minute = None
        self._month = None
        self._position = None
        self._seconds = None
        self._year = None

        if _date is not None:
            self._date = _date
        if day_of_week is not None:
            self.day_of_week = day_of_week
        if hour is not None:
            self.hour = hour
        if milliseconds is not None:
            self.milliseconds = milliseconds
        if minute is not None:
            self.minute = minute
        if month is not None:
            self.month = month
        if position is not None:
            self.position = position
        if seconds is not None:
            self.seconds = seconds
        if year is not None:
            self.year = year


    @property
    def _date(self) -> datetime:
        """
        Date and time that indicate when to begin using the Standard/Daylight time.             

        :return: The _date of this MapiCalendarTimeZoneRuleDto.
        :rtype: datetime
        """
        return self.__date

    @_date.setter
    def _date(self, _date: datetime):
        """
        Date and time that indicate when to begin using the Standard/Daylight time.             

        :param _date: The _date of this MapiCalendarTimeZoneRuleDto.
        :type: datetime
        """
        if _date is None:
            raise ValueError("Invalid value for `_date`, must not be `None`")
        self.__date = _date

    @property
    def day_of_week(self) -> str:
        """
        Day of week. Enum, available values: Sunday, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday

        :return: The day_of_week of this MapiCalendarTimeZoneRuleDto.
        :rtype: str
        """
        return self._day_of_week

    @day_of_week.setter
    def day_of_week(self, day_of_week: str):
        """
        Day of week. Enum, available values: Sunday, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday

        :param day_of_week: The day_of_week of this MapiCalendarTimeZoneRuleDto.
        :type: str
        """
        if day_of_week is None:
            raise ValueError("Invalid value for `day_of_week`, must not be `None`")
        self._day_of_week = day_of_week

    @property
    def hour(self) -> int:
        """
        Hour.             

        :return: The hour of this MapiCalendarTimeZoneRuleDto.
        :rtype: int
        """
        return self._hour

    @hour.setter
    def hour(self, hour: int):
        """
        Hour.             

        :param hour: The hour of this MapiCalendarTimeZoneRuleDto.
        :type: int
        """
        if hour is None:
            raise ValueError("Invalid value for `hour`, must not be `None`")
        self._hour = hour

    @property
    def milliseconds(self) -> int:
        """
        Milliseconds.             

        :return: The milliseconds of this MapiCalendarTimeZoneRuleDto.
        :rtype: int
        """
        return self._milliseconds

    @milliseconds.setter
    def milliseconds(self, milliseconds: int):
        """
        Milliseconds.             

        :param milliseconds: The milliseconds of this MapiCalendarTimeZoneRuleDto.
        :type: int
        """
        if milliseconds is None:
            raise ValueError("Invalid value for `milliseconds`, must not be `None`")
        self._milliseconds = milliseconds

    @property
    def minute(self) -> int:
        """
        Minute.             

        :return: The minute of this MapiCalendarTimeZoneRuleDto.
        :rtype: int
        """
        return self._minute

    @minute.setter
    def minute(self, minute: int):
        """
        Minute.             

        :param minute: The minute of this MapiCalendarTimeZoneRuleDto.
        :type: int
        """
        if minute is None:
            raise ValueError("Invalid value for `minute`, must not be `None`")
        self._minute = minute

    @property
    def month(self) -> int:
        """
        Month.             

        :return: The month of this MapiCalendarTimeZoneRuleDto.
        :rtype: int
        """
        return self._month

    @month.setter
    def month(self, month: int):
        """
        Month.             

        :param month: The month of this MapiCalendarTimeZoneRuleDto.
        :type: int
        """
        if month is None:
            raise ValueError("Invalid value for `month`, must not be `None`")
        if month is not None and month > 12:
            raise ValueError("Invalid value for `month`, must be a value less than or equal to `12`")
        if month is not None and month < 0:
            raise ValueError("Invalid value for `month`, must be a value greater than or equal to `0`")
        self._month = month

    @property
    def position(self) -> str:
        """
        Day positions, typically found in a month. Enum, available values: None, First, Second, Third, Fourth, Last

        :return: The position of this MapiCalendarTimeZoneRuleDto.
        :rtype: str
        """
        return self._position

    @position.setter
    def position(self, position: str):
        """
        Day positions, typically found in a month. Enum, available values: None, First, Second, Third, Fourth, Last

        :param position: The position of this MapiCalendarTimeZoneRuleDto.
        :type: str
        """
        if position is None:
            raise ValueError("Invalid value for `position`, must not be `None`")
        self._position = position

    @property
    def seconds(self) -> int:
        """
        Seconds.             

        :return: The seconds of this MapiCalendarTimeZoneRuleDto.
        :rtype: int
        """
        return self._seconds

    @seconds.setter
    def seconds(self, seconds: int):
        """
        Seconds.             

        :param seconds: The seconds of this MapiCalendarTimeZoneRuleDto.
        :type: int
        """
        if seconds is None:
            raise ValueError("Invalid value for `seconds`, must not be `None`")
        self._seconds = seconds

    @property
    def year(self) -> int:
        """
        Year.             

        :return: The year of this MapiCalendarTimeZoneRuleDto.
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year: int):
        """
        Year.             

        :param year: The year of this MapiCalendarTimeZoneRuleDto.
        :type: int
        """
        if year is None:
            raise ValueError("Invalid value for `year`, must not be `None`")
        self._year = year

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiCalendarTimeZoneRuleDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="EmailClientAccount.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.email_client_account_credentials import EmailClientAccountCredentials
from AsposeEmailCloudSdk.models.storage_file_location import StorageFileLocation


class EmailClientAccount(object):
    """A universal email client account             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'host': 'str',
        'port': 'int',
        'security_options': 'str',
        'protocol_type': 'str',
        'credentials': 'EmailClientAccountCredentials',
        'cache_file': 'StorageFileLocation'
    }

    attribute_map = {
        'host': 'host',
        'port': 'port',
        'security_options': 'securityOptions',
        'protocol_type': 'protocolType',
        'credentials': 'credentials',
        'cache_file': 'cacheFile'
    }

    def __init__(self, host: str = None, port: int = None, security_options: str = None, protocol_type: str = None, credentials: EmailClientAccountCredentials = None, cache_file: StorageFileLocation = None):
        """
        A universal email client account             
        :param host: Mail server host name or IP address             
        :type host: str
        :param port: Mail server port             
        :type port: int
        :param security_options: Email account security mode Enum, available values: None, SSLExplicit, SSLImplicit, SSLAuto, Auto
        :type security_options: str
        :param protocol_type: Type of connection protocol. Enum, available values: IMAP, POP3, SMTP, EWS, WebDav
        :type protocol_type: str
        :param credentials: Email client account credentials             
        :type credentials: EmailClientAccountCredentials
        :param cache_file: File with messages cache. Used to provide extra functions, which are not supported by account             
        :type cache_file: StorageFileLocation
        """

        self._host = None
        self._port = None
        self._security_options = None
        self._protocol_type = None
        self._credentials = None
        self._cache_file = None

        if host is not None:
            self.host = host
        if port is not None:
            self.port = port
        if security_options is not None:
            self.security_options = security_options
        if protocol_type is not None:
            self.protocol_type = protocol_type
        if credentials is not None:
            self.credentials = credentials
        if cache_file is not None:
            self.cache_file = cache_file


    @property
    def host(self) -> str:
        """
        Mail server host name or IP address             

        :return: The host of this EmailClientAccount.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host: str):
        """
        Mail server host name or IP address             

        :param host: The host of this EmailClientAccount.
        :type: str
        """
        if host is None:
            raise ValueError("Invalid value for `host`, must not be `None`")
        if host is not None and len(host) < 1:
            raise ValueError("Invalid value for `host`, length must be greater than or equal to `1`")
        self._host = host

    @property
    def port(self) -> int:
        """
        Mail server port             

        :return: The port of this EmailClientAccount.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port: int):
        """
        Mail server port             

        :param port: The port of this EmailClientAccount.
        :type: int
        """
        if port is None:
            raise ValueError("Invalid value for `port`, must not be `None`")
        if port is not None and port > 2147483647:
            raise ValueError("Invalid value for `port`, must be a value less than or equal to `2147483647`")
        if port is not None and port < 1:
            raise ValueError("Invalid value for `port`, must be a value greater than or equal to `1`")
        self._port = port

    @property
    def security_options(self) -> str:
        """
        Email account security mode Enum, available values: None, SSLExplicit, SSLImplicit, SSLAuto, Auto

        :return: The security_options of this EmailClientAccount.
        :rtype: str
        """
        return self._security_options

    @security_options.setter
    def security_options(self, security_options: str):
        """
        Email account security mode Enum, available values: None, SSLExplicit, SSLImplicit, SSLAuto, Auto

        :param security_options: The security_options of this EmailClientAccount.
        :type: str
        """
        if security_options is None:
            raise ValueError("Invalid value for `security_options`, must not be `None`")
        self._security_options = security_options

    @property
    def protocol_type(self) -> str:
        """
        Type of connection protocol. Enum, available values: IMAP, POP3, SMTP, EWS, WebDav

        :return: The protocol_type of this EmailClientAccount.
        :rtype: str
        """
        return self._protocol_type

    @protocol_type.setter
    def protocol_type(self, protocol_type: str):
        """
        Type of connection protocol. Enum, available values: IMAP, POP3, SMTP, EWS, WebDav

        :param protocol_type: The protocol_type of this EmailClientAccount.
        :type: str
        """
        if protocol_type is None:
            raise ValueError("Invalid value for `protocol_type`, must not be `None`")
        self._protocol_type = protocol_type

    @property
    def credentials(self) -> EmailClientAccountCredentials:
        """
        Email client account credentials             

        :return: The credentials of this EmailClientAccount.
        :rtype: EmailClientAccountCredentials
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials: EmailClientAccountCredentials):
        """
        Email client account credentials             

        :param credentials: The credentials of this EmailClientAccount.
        :type: EmailClientAccountCredentials
        """
        if credentials is None:
            raise ValueError("Invalid value for `credentials`, must not be `None`")
        self._credentials = credentials

    @property
    def cache_file(self) -> StorageFileLocation:
        """
        File with messages cache. Used to provide extra functions, which are not supported by account             

        :return: The cache_file of this EmailClientAccount.
        :rtype: StorageFileLocation
        """
        return self._cache_file

    @cache_file.setter
    def cache_file(self, cache_file: StorageFileLocation):
        """
        File with messages cache. Used to provide extra functions, which are not supported by account             

        :param cache_file: The cache_file of this EmailClientAccount.
        :type: StorageFileLocation
        """
        self._cache_file = cache_file

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailClientAccount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiContactElectronicAddressDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime


class MapiContactElectronicAddressDto(object):
    """Refers to the group of properties that define the e-mail address or fax address for a contact.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address_type': 'str',
        'display_name': 'str',
        'email_address': 'str',
        'fax_number': 'str',
        'is_empty': 'bool',
        'original_display_name': 'str'
    }

    attribute_map = {
        'address_type': 'addressType',
        'display_name': 'displayName',
        'email_address': 'emailAddress',
        'fax_number': 'faxNumber',
        'is_empty': 'isEmpty',
        'original_display_name': 'originalDisplayName'
    }

    def __init__(self, address_type: str = None, display_name: str = None, email_address: str = None, fax_number: str = None, is_empty: bool = None, original_display_name: str = None):
        """
        Refers to the group of properties that define the e-mail address or fax address for a contact.             
        :param address_type: Address type of an electronic address
        :type address_type: str
        :param display_name: User-readable display name for the e-mail address
        :type display_name: str
        :param email_address: E-mail address of the contact
        :type email_address: str
        :param fax_number: Telephone number of the mail user's primary fax machine
        :type fax_number: str
        :param is_empty: Shows if MapiContactElectronicAddress is empty
        :type is_empty: bool
        :param original_display_name: SMTP e-mail address that corresponds to the e-mail address for the Contact object.
        :type original_display_name: str
        """

        self._address_type = None
        self._display_name = None
        self._email_address = None
        self._fax_number = None
        self._is_empty = None
        self._original_display_name = None

        if address_type is not None:
            self.address_type = address_type
        if display_name is not None:
            self.display_name = display_name
        if email_address is not None:
            self.email_address = email_address
        if fax_number is not None:
            self.fax_number = fax_number
        if is_empty is not None:
            self.is_empty = is_empty
        if original_display_name is not None:
            self.original_display_name = original_display_name


    @property
    def address_type(self) -> str:
        """
        Address type of an electronic address

        :return: The address_type of this MapiContactElectronicAddressDto.
        :rtype: str
        """
        return self._address_type

    @address_type.setter
    def address_type(self, address_type: str):
        """
        Address type of an electronic address

        :param address_type: The address_type of this MapiContactElectronicAddressDto.
        :type: str
        """
        self._address_type = address_type

    @property
    def display_name(self) -> str:
        """
        User-readable display name for the e-mail address

        :return: The display_name of this MapiContactElectronicAddressDto.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: str):
        """
        User-readable display name for the e-mail address

        :param display_name: The display_name of this MapiContactElectronicAddressDto.
        :type: str
        """
        self._display_name = display_name

    @property
    def email_address(self) -> str:
        """
        E-mail address of the contact

        :return: The email_address of this MapiContactElectronicAddressDto.
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address: str):
        """
        E-mail address of the contact

        :param email_address: The email_address of this MapiContactElectronicAddressDto.
        :type: str
        """
        self._email_address = email_address

    @property
    def fax_number(self) -> str:
        """
        Telephone number of the mail user's primary fax machine

        :return: The fax_number of this MapiContactElectronicAddressDto.
        :rtype: str
        """
        return self._fax_number

    @fax_number.setter
    def fax_number(self, fax_number: str):
        """
        Telephone number of the mail user's primary fax machine

        :param fax_number: The fax_number of this MapiContactElectronicAddressDto.
        :type: str
        """
        self._fax_number = fax_number

    @property
    def is_empty(self) -> bool:
        """
        Shows if MapiContactElectronicAddress is empty

        :return: The is_empty of this MapiContactElectronicAddressDto.
        :rtype: bool
        """
        return self._is_empty

    @is_empty.setter
    def is_empty(self, is_empty: bool):
        """
        Shows if MapiContactElectronicAddress is empty

        :param is_empty: The is_empty of this MapiContactElectronicAddressDto.
        :type: bool
        """
        if is_empty is None:
            raise ValueError("Invalid value for `is_empty`, must not be `None`")
        self._is_empty = is_empty

    @property
    def original_display_name(self) -> str:
        """
        SMTP e-mail address that corresponds to the e-mail address for the Contact object.

        :return: The original_display_name of this MapiContactElectronicAddressDto.
        :rtype: str
        """
        return self._original_display_name

    @original_display_name.setter
    def original_display_name(self, original_display_name: str):
        """
        SMTP e-mail address that corresponds to the e-mail address for the Contact object.

        :param original_display_name: The original_display_name of this MapiContactElectronicAddressDto.
        :type: str
        """
        self._original_display_name = original_display_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiContactElectronicAddressDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiMessageDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.mapi_attachment_dto import MapiAttachmentDto
from AsposeEmailCloudSdk.models.mapi_message_item_base_dto import MapiMessageItemBaseDto
from AsposeEmailCloudSdk.models.mapi_property_dto import MapiPropertyDto
from AsposeEmailCloudSdk.models.mapi_recipient_dto import MapiRecipientDto


class MapiMessageDto(MapiMessageItemBaseDto):
    """Represents an Outlook Message format document.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attachments': 'list[MapiAttachmentDto]',
        'billing': 'str',
        'body': 'str',
        'body_html': 'str',
        'body_rtf': 'str',
        'body_type': 'str',
        'categories': 'list[str]',
        'companies': 'list[str]',
        'item_id': 'str',
        'message_class': 'str',
        'mileage': 'str',
        'recipients': 'list[MapiRecipientDto]',
        'sensitivity': 'str',
        'subject': 'str',
        'subject_prefix': 'str',
        'properties': 'list[MapiPropertyDto]',
        'discriminator': 'str',
        'message_body': 'str',
        'client_submit_time': 'datetime',
        'conversation_topic': 'str',
        'delivery_time': 'datetime',
        'display_bcc': 'str',
        'display_cc': 'str',
        'display_name': 'str',
        'display_name_prefix': 'str',
        'display_to': 'str',
        'flags': 'list[str]',
        'headers': 'dict(str, str)',
        'internet_message_id': 'str',
        'message_format': 'str',
        'normalized_subject': 'str',
        'read_receipt_requested': 'bool',
        'reply_to': 'str',
        'sender_address_type': 'str',
        'sender_email_address': 'str',
        'sender_name': 'str',
        'sender_smtp_address': 'str',
        'sent_representing_address_type': 'str',
        'sent_representing_email_address': 'str',
        'sent_representing_name': 'str',
        'sent_representing_smtp_address': 'str',
        'transport_message_headers': 'str'
    }

    attribute_map = {
        'attachments': 'attachments',
        'billing': 'billing',
        'body': 'body',
        'body_html': 'bodyHtml',
        'body_rtf': 'bodyRtf',
        'body_type': 'bodyType',
        'categories': 'categories',
        'companies': 'companies',
        'item_id': 'itemId',
        'message_class': 'messageClass',
        'mileage': 'mileage',
        'recipients': 'recipients',
        'sensitivity': 'sensitivity',
        'subject': 'subject',
        'subject_prefix': 'subjectPrefix',
        'properties': 'properties',
        'discriminator': 'discriminator',
        'message_body': 'messageBody',
        'client_submit_time': 'clientSubmitTime',
        'conversation_topic': 'conversationTopic',
        'delivery_time': 'deliveryTime',
        'display_bcc': 'displayBcc',
        'display_cc': 'displayCc',
        'display_name': 'displayName',
        'display_name_prefix': 'displayNamePrefix',
        'display_to': 'displayTo',
        'flags': 'flags',
        'headers': 'headers',
        'internet_message_id': 'internetMessageId',
        'message_format': 'messageFormat',
        'normalized_subject': 'normalizedSubject',
        'read_receipt_requested': 'readReceiptRequested',
        'reply_to': 'replyTo',
        'sender_address_type': 'senderAddressType',
        'sender_email_address': 'senderEmailAddress',
        'sender_name': 'senderName',
        'sender_smtp_address': 'senderSmtpAddress',
        'sent_representing_address_type': 'sentRepresentingAddressType',
        'sent_representing_email_address': 'sentRepresentingEmailAddress',
        'sent_representing_name': 'sentRepresentingName',
        'sent_representing_smtp_address': 'sentRepresentingSmtpAddress',
        'transport_message_headers': 'transportMessageHeaders'
    }

    def __init__(self, attachments: List[MapiAttachmentDto] = None, billing: str = None, body: str = None, body_html: str = None, body_rtf: str = None, body_type: str = None, categories: List[str] = None, companies: List[str] = None, item_id: str = None, message_class: str = None, mileage: str = None, recipients: List[MapiRecipientDto] = None, sensitivity: str = None, subject: str = None, subject_prefix: str = None, properties: List[MapiPropertyDto] = None, message_body: str = None, client_submit_time: datetime = None, conversation_topic: str = None, delivery_time: datetime = None, display_bcc: str = None, display_cc: str = None, display_name: str = None, display_name_prefix: str = None, display_to: str = None, flags: List[str] = None, headers: Dict[str, str] = None, internet_message_id: str = None, message_format: str = None, normalized_subject: str = None, read_receipt_requested: bool = None, reply_to: str = None, sender_address_type: str = None, sender_email_address: str = None, sender_name: str = None, sender_smtp_address: str = None, sent_representing_address_type: str = None, sent_representing_email_address: str = None, sent_representing_name: str = None, sent_representing_smtp_address: str = None, transport_message_headers: str = None):
        """
        Represents an Outlook Message format document.             
        :param attachments: Message item attachments.             
        :type attachments: List[MapiAttachmentDto]
        :param billing: Billing information associated with an item.             
        :type billing: str
        :param body: Message text.             
        :type body: str
        :param body_html: Gets the BodyRtf of the message converted to HTML, if present, otherwise an empty string.             
        :type body_html: str
        :param body_rtf: RTF formatted message text.             
        :type body_rtf: str
        :param body_type: The content type of message body. Enum, available values: PlainText, Html, Rtf
        :type body_type: str
        :param categories: Contains keywords or categories for the message object.             
        :type categories: List[str]
        :param companies: Contains the names of the companies that are associated with an item.             
        :type companies: List[str]
        :param item_id: The item id, uses with a server.             
        :type item_id: str
        :param message_class: Case-sensitive string that identifies the sender-defined message class, such as IPM.Note. The message class specifies the type, purpose, or content of the message.             
        :type message_class: str
        :param mileage: Contains the mileage information that is associated with an item.             
        :type mileage: str
        :param recipients: Recipients of the message.             
        :type recipients: List[MapiRecipientDto]
        :param sensitivity: Contains values that indicate the message sensitivity. Enum, available values: None, Personal, Private, CompanyConfidential
        :type sensitivity: str
        :param subject: Subject of the message.             
        :type subject: str
        :param subject_prefix: Subject prefix that typically indicates some action on a message, such as \"FW: \" for forwarding.             
        :type subject_prefix: str
        :param properties: List of MAPI properties             
        :type properties: List[MapiPropertyDto]
        :param message_body: Message text             
        :type message_body: str
        :param client_submit_time: Date and time the message sender submitted a message.             
        :type client_submit_time: datetime
        :param conversation_topic: Topic of the first message in a conversation thread.             
        :type conversation_topic: str
        :param delivery_time: Date and time a message was delivered.             
        :type delivery_time: datetime
        :param display_bcc: List of the display names of any blind carbon copy (BCC) message recipients, separated by semicolons (;).             
        :type display_bcc: str
        :param display_cc: List of the display names of any carbon copy (CC) message recipients, separated by semicolons (;).             
        :type display_cc: str
        :param display_name: Display name for the message.             
        :type display_name: str
        :param display_name_prefix: Prefix of the display name.             
        :type display_name_prefix: str
        :param display_to: List of the display names of the primary (To) message recipients, separated by semicolons (;).             
        :type display_to: str
        :param flags: Message flags.             
        :type flags: List[str]
        :param headers: Transport message headers             
        :type headers: Dict[str, str]
        :param internet_message_id: Internet message id of the message.             
        :type internet_message_id: str
        :param message_format: Represents outlook message format. Enum, available values: Ascii, Unicode
        :type message_format: str
        :param normalized_subject: Normalized subject of the message.             
        :type normalized_subject: str
        :param read_receipt_requested: Value indicating whether the read receipt is requested.
        :type read_receipt_requested: bool
        :param reply_to: Reply to names.
        :type reply_to: str
        :param sender_address_type: Message sender's e-mail address type.
        :type sender_address_type: str
        :param sender_email_address: Message sender's e-mail address.
        :type sender_email_address: str
        :param sender_name: Message sender's display name.
        :type sender_name: str
        :param sender_smtp_address: Message sender's e-mail address.
        :type sender_smtp_address: str
        :param sent_representing_address_type: Address type for the messaging user represented by the sender.
        :type sent_representing_address_type: str
        :param sent_representing_email_address: E-mail address for the messaging user represented by the sender.
        :type sent_representing_email_address: str
        :param sent_representing_name: Display name for the messaging user represented by the sender.
        :type sent_representing_name: str
        :param sent_representing_smtp_address: E-mail address for the messaging user represented by the sender.
        :type sent_representing_smtp_address: str
        :param transport_message_headers: Transport-specific message envelope information.
        :type transport_message_headers: str
        """
        super(MapiMessageDto, self).__init__()

        self._message_body = None
        self._client_submit_time = None
        self._conversation_topic = None
        self._delivery_time = None
        self._display_bcc = None
        self._display_cc = None
        self._display_name = None
        self._display_name_prefix = None
        self._display_to = None
        self._flags = None
        self._headers = None
        self._internet_message_id = None
        self._message_format = None
        self._normalized_subject = None
        self._read_receipt_requested = None
        self._reply_to = None
        self._sender_address_type = None
        self._sender_email_address = None
        self._sender_name = None
        self._sender_smtp_address = None
        self._sent_representing_address_type = None
        self._sent_representing_email_address = None
        self._sent_representing_name = None
        self._sent_representing_smtp_address = None
        self._transport_message_headers = None

        if attachments is not None:
            self.attachments = attachments
        if billing is not None:
            self.billing = billing
        if body is not None:
            self.body = body
        if body_html is not None:
            self.body_html = body_html
        if body_rtf is not None:
            self.body_rtf = body_rtf
        if body_type is not None:
            self.body_type = body_type
        if categories is not None:
            self.categories = categories
        if companies is not None:
            self.companies = companies
        if item_id is not None:
            self.item_id = item_id
        if message_class is not None:
            self.message_class = message_class
        if mileage is not None:
            self.mileage = mileage
        if recipients is not None:
            self.recipients = recipients
        if sensitivity is not None:
            self.sensitivity = sensitivity
        if subject is not None:
            self.subject = subject
        if subject_prefix is not None:
            self.subject_prefix = subject_prefix
        if properties is not None:
            self.properties = properties
        if message_body is not None:
            self.message_body = message_body
        if client_submit_time is not None:
            self.client_submit_time = client_submit_time
        if conversation_topic is not None:
            self.conversation_topic = conversation_topic
        if delivery_time is not None:
            self.delivery_time = delivery_time
        if display_bcc is not None:
            self.display_bcc = display_bcc
        if display_cc is not None:
            self.display_cc = display_cc
        if display_name is not None:
            self.display_name = display_name
        if display_name_prefix is not None:
            self.display_name_prefix = display_name_prefix
        if display_to is not None:
            self.display_to = display_to
        if flags is not None:
            self.flags = flags
        if headers is not None:
            self.headers = headers
        if internet_message_id is not None:
            self.internet_message_id = internet_message_id
        if message_format is not None:
            self.message_format = message_format
        if normalized_subject is not None:
            self.normalized_subject = normalized_subject
        if read_receipt_requested is not None:
            self.read_receipt_requested = read_receipt_requested
        if reply_to is not None:
            self.reply_to = reply_to
        if sender_address_type is not None:
            self.sender_address_type = sender_address_type
        if sender_email_address is not None:
            self.sender_email_address = sender_email_address
        if sender_name is not None:
            self.sender_name = sender_name
        if sender_smtp_address is not None:
            self.sender_smtp_address = sender_smtp_address
        if sent_representing_address_type is not None:
            self.sent_representing_address_type = sent_representing_address_type
        if sent_representing_email_address is not None:
            self.sent_representing_email_address = sent_representing_email_address
        if sent_representing_name is not None:
            self.sent_representing_name = sent_representing_name
        if sent_representing_smtp_address is not None:
            self.sent_representing_smtp_address = sent_representing_smtp_address
        if transport_message_headers is not None:
            self.transport_message_headers = transport_message_headers


    @property
    def message_body(self) -> str:
        """
        Message text             

        :return: The message_body of this MapiMessageDto.
        :rtype: str
        """
        return self._message_body

    @message_body.setter
    def message_body(self, message_body: str):
        """
        Message text             

        :param message_body: The message_body of this MapiMessageDto.
        :type: str
        """
        self._message_body = message_body

    @property
    def client_submit_time(self) -> datetime:
        """
        Date and time the message sender submitted a message.             

        :return: The client_submit_time of this MapiMessageDto.
        :rtype: datetime
        """
        return self._client_submit_time

    @client_submit_time.setter
    def client_submit_time(self, client_submit_time: datetime):
        """
        Date and time the message sender submitted a message.             

        :param client_submit_time: The client_submit_time of this MapiMessageDto.
        :type: datetime
        """
        if client_submit_time is None:
            raise ValueError("Invalid value for `client_submit_time`, must not be `None`")
        self._client_submit_time = client_submit_time

    @property
    def conversation_topic(self) -> str:
        """
        Topic of the first message in a conversation thread.             

        :return: The conversation_topic of this MapiMessageDto.
        :rtype: str
        """
        return self._conversation_topic

    @conversation_topic.setter
    def conversation_topic(self, conversation_topic: str):
        """
        Topic of the first message in a conversation thread.             

        :param conversation_topic: The conversation_topic of this MapiMessageDto.
        :type: str
        """
        self._conversation_topic = conversation_topic

    @property
    def delivery_time(self) -> datetime:
        """
        Date and time a message was delivered.             

        :return: The delivery_time of this MapiMessageDto.
        :rtype: datetime
        """
        return self._delivery_time

    @delivery_time.setter
    def delivery_time(self, delivery_time: datetime):
        """
        Date and time a message was delivered.             

        :param delivery_time: The delivery_time of this MapiMessageDto.
        :type: datetime
        """
        if delivery_time is None:
            raise ValueError("Invalid value for `delivery_time`, must not be `None`")
        self._delivery_time = delivery_time

    @property
    def display_bcc(self) -> str:
        """
        List of the display names of any blind carbon copy (BCC) message recipients, separated by semicolons (;).             

        :return: The display_bcc of this MapiMessageDto.
        :rtype: str
        """
        return self._display_bcc

    @display_bcc.setter
    def display_bcc(self, display_bcc: str):
        """
        List of the display names of any blind carbon copy (BCC) message recipients, separated by semicolons (;).             

        :param display_bcc: The display_bcc of this MapiMessageDto.
        :type: str
        """
        self._display_bcc = display_bcc

    @property
    def display_cc(self) -> str:
        """
        List of the display names of any carbon copy (CC) message recipients, separated by semicolons (;).             

        :return: The display_cc of this MapiMessageDto.
        :rtype: str
        """
        return self._display_cc

    @display_cc.setter
    def display_cc(self, display_cc: str):
        """
        List of the display names of any carbon copy (CC) message recipients, separated by semicolons (;).             

        :param display_cc: The display_cc of this MapiMessageDto.
        :type: str
        """
        self._display_cc = display_cc

    @property
    def display_name(self) -> str:
        """
        Display name for the message.             

        :return: The display_name of this MapiMessageDto.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: str):
        """
        Display name for the message.             

        :param display_name: The display_name of this MapiMessageDto.
        :type: str
        """
        self._display_name = display_name

    @property
    def display_name_prefix(self) -> str:
        """
        Prefix of the display name.             

        :return: The display_name_prefix of this MapiMessageDto.
        :rtype: str
        """
        return self._display_name_prefix

    @display_name_prefix.setter
    def display_name_prefix(self, display_name_prefix: str):
        """
        Prefix of the display name.             

        :param display_name_prefix: The display_name_prefix of this MapiMessageDto.
        :type: str
        """
        self._display_name_prefix = display_name_prefix

    @property
    def display_to(self) -> str:
        """
        List of the display names of the primary (To) message recipients, separated by semicolons (;).             

        :return: The display_to of this MapiMessageDto.
        :rtype: str
        """
        return self._display_to

    @display_to.setter
    def display_to(self, display_to: str):
        """
        List of the display names of the primary (To) message recipients, separated by semicolons (;).             

        :param display_to: The display_to of this MapiMessageDto.
        :type: str
        """
        self._display_to = display_to

    @property
    def flags(self) -> List[str]:
        """
        Message flags.              Items: Mapi message flags. Enum, available values: MsgFlagZero, MsgFlagRead, MsgFlagUnmodified, MsgFlagSubmit, MsgFlagUnsent, MsgFlagHasAttach, MsgFlagFromMe, MsgFlagAssociated, MsgFlagResend, MsgFlagNotifyRead, MsgFlagNotifyUnread, MsgFlagEverRead, MsgFlagOriginX400, MsgFlagOriginInternet, MsgFlagOriginMiscExt

        :return: The flags of this MapiMessageDto.
        :rtype: list[str]
        """
        return self._flags

    @flags.setter
    def flags(self, flags: List[str]):
        """
        Message flags.              Items: Mapi message flags. Enum, available values: MsgFlagZero, MsgFlagRead, MsgFlagUnmodified, MsgFlagSubmit, MsgFlagUnsent, MsgFlagHasAttach, MsgFlagFromMe, MsgFlagAssociated, MsgFlagResend, MsgFlagNotifyRead, MsgFlagNotifyUnread, MsgFlagEverRead, MsgFlagOriginX400, MsgFlagOriginInternet, MsgFlagOriginMiscExt

        :param flags: The flags of this MapiMessageDto.
        :type: list[str]
        """
        self._flags = flags

    @property
    def headers(self) -> Dict[str, str]:
        """
        Transport message headers             

        :return: The headers of this MapiMessageDto.
        :rtype: dict(str, str)
        """
        return self._headers

    @headers.setter
    def headers(self, headers: Dict[str, str]):
        """
        Transport message headers             

        :param headers: The headers of this MapiMessageDto.
        :type: dict(str, str)
        """
        self._headers = headers

    @property
    def internet_message_id(self) -> str:
        """
        Internet message id of the message.             

        :return: The internet_message_id of this MapiMessageDto.
        :rtype: str
        """
        return self._internet_message_id

    @internet_message_id.setter
    def internet_message_id(self, internet_message_id: str):
        """
        Internet message id of the message.             

        :param internet_message_id: The internet_message_id of this MapiMessageDto.
        :type: str
        """
        self._internet_message_id = internet_message_id

    @property
    def message_format(self) -> str:
        """
        Represents outlook message format. Enum, available values: Ascii, Unicode

        :return: The message_format of this MapiMessageDto.
        :rtype: str
        """
        return self._message_format

    @message_format.setter
    def message_format(self, message_format: str):
        """
        Represents outlook message format. Enum, available values: Ascii, Unicode

        :param message_format: The message_format of this MapiMessageDto.
        :type: str
        """
        if message_format is None:
            raise ValueError("Invalid value for `message_format`, must not be `None`")
        self._message_format = message_format

    @property
    def normalized_subject(self) -> str:
        """
        Normalized subject of the message.             

        :return: The normalized_subject of this MapiMessageDto.
        :rtype: str
        """
        return self._normalized_subject

    @normalized_subject.setter
    def normalized_subject(self, normalized_subject: str):
        """
        Normalized subject of the message.             

        :param normalized_subject: The normalized_subject of this MapiMessageDto.
        :type: str
        """
        self._normalized_subject = normalized_subject

    @property
    def read_receipt_requested(self) -> bool:
        """
        Value indicating whether the read receipt is requested.

        :return: The read_receipt_requested of this MapiMessageDto.
        :rtype: bool
        """
        return self._read_receipt_requested

    @read_receipt_requested.setter
    def read_receipt_requested(self, read_receipt_requested: bool):
        """
        Value indicating whether the read receipt is requested.

        :param read_receipt_requested: The read_receipt_requested of this MapiMessageDto.
        :type: bool
        """
        if read_receipt_requested is None:
            raise ValueError("Invalid value for `read_receipt_requested`, must not be `None`")
        self._read_receipt_requested = read_receipt_requested

    @property
    def reply_to(self) -> str:
        """
        Reply to names.

        :return: The reply_to of this MapiMessageDto.
        :rtype: str
        """
        return self._reply_to

    @reply_to.setter
    def reply_to(self, reply_to: str):
        """
        Reply to names.

        :param reply_to: The reply_to of this MapiMessageDto.
        :type: str
        """
        self._reply_to = reply_to

    @property
    def sender_address_type(self) -> str:
        """
        Message sender's e-mail address type.

        :return: The sender_address_type of this MapiMessageDto.
        :rtype: str
        """
        return self._sender_address_type

    @sender_address_type.setter
    def sender_address_type(self, sender_address_type: str):
        """
        Message sender's e-mail address type.

        :param sender_address_type: The sender_address_type of this MapiMessageDto.
        :type: str
        """
        self._sender_address_type = sender_address_type

    @property
    def sender_email_address(self) -> str:
        """
        Message sender's e-mail address.

        :return: The sender_email_address of this MapiMessageDto.
        :rtype: str
        """
        return self._sender_email_address

    @sender_email_address.setter
    def sender_email_address(self, sender_email_address: str):
        """
        Message sender's e-mail address.

        :param sender_email_address: The sender_email_address of this MapiMessageDto.
        :type: str
        """
        self._sender_email_address = sender_email_address

    @property
    def sender_name(self) -> str:
        """
        Message sender's display name.

        :return: The sender_name of this MapiMessageDto.
        :rtype: str
        """
        return self._sender_name

    @sender_name.setter
    def sender_name(self, sender_name: str):
        """
        Message sender's display name.

        :param sender_name: The sender_name of this MapiMessageDto.
        :type: str
        """
        self._sender_name = sender_name

    @property
    def sender_smtp_address(self) -> str:
        """
        Message sender's e-mail address.

        :return: The sender_smtp_address of this MapiMessageDto.
        :rtype: str
        """
        return self._sender_smtp_address

    @sender_smtp_address.setter
    def sender_smtp_address(self, sender_smtp_address: str):
        """
        Message sender's e-mail address.

        :param sender_smtp_address: The sender_smtp_address of this MapiMessageDto.
        :type: str
        """
        self._sender_smtp_address = sender_smtp_address

    @property
    def sent_representing_address_type(self) -> str:
        """
        Address type for the messaging user represented by the sender.

        :return: The sent_representing_address_type of this MapiMessageDto.
        :rtype: str
        """
        return self._sent_representing_address_type

    @sent_representing_address_type.setter
    def sent_representing_address_type(self, sent_representing_address_type: str):
        """
        Address type for the messaging user represented by the sender.

        :param sent_representing_address_type: The sent_representing_address_type of this MapiMessageDto.
        :type: str
        """
        self._sent_representing_address_type = sent_representing_address_type

    @property
    def sent_representing_email_address(self) -> str:
        """
        E-mail address for the messaging user represented by the sender.

        :return: The sent_representing_email_address of this MapiMessageDto.
        :rtype: str
        """
        return self._sent_representing_email_address

    @sent_representing_email_address.setter
    def sent_representing_email_address(self, sent_representing_email_address: str):
        """
        E-mail address for the messaging user represented by the sender.

        :param sent_representing_email_address: The sent_representing_email_address of this MapiMessageDto.
        :type: str
        """
        self._sent_representing_email_address = sent_representing_email_address

    @property
    def sent_representing_name(self) -> str:
        """
        Display name for the messaging user represented by the sender.

        :return: The sent_representing_name of this MapiMessageDto.
        :rtype: str
        """
        return self._sent_representing_name

    @sent_representing_name.setter
    def sent_representing_name(self, sent_representing_name: str):
        """
        Display name for the messaging user represented by the sender.

        :param sent_representing_name: The sent_representing_name of this MapiMessageDto.
        :type: str
        """
        self._sent_representing_name = sent_representing_name

    @property
    def sent_representing_smtp_address(self) -> str:
        """
        E-mail address for the messaging user represented by the sender.

        :return: The sent_representing_smtp_address of this MapiMessageDto.
        :rtype: str
        """
        return self._sent_representing_smtp_address

    @sent_representing_smtp_address.setter
    def sent_representing_smtp_address(self, sent_representing_smtp_address: str):
        """
        E-mail address for the messaging user represented by the sender.

        :param sent_representing_smtp_address: The sent_representing_smtp_address of this MapiMessageDto.
        :type: str
        """
        self._sent_representing_smtp_address = sent_representing_smtp_address

    @property
    def transport_message_headers(self) -> str:
        """
        Transport-specific message envelope information.

        :return: The transport_message_headers of this MapiMessageDto.
        :rtype: str
        """
        return self._transport_message_headers

    @transport_message_headers.setter
    def transport_message_headers(self, transport_message_headers: str):
        """
        Transport-specific message envelope information.

        :param transport_message_headers: The transport_message_headers of this MapiMessageDto.
        :type: str
        """
        self._transport_message_headers = transport_message_headers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiMessageDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiPidNamePropertyDescriptor.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.mapi_pid_property_descriptor import MapiPidPropertyDescriptor


class MapiPidNamePropertyDescriptor(MapiPidPropertyDescriptor):
    """Property identified by a string name along with a property set             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'discriminator': 'str',
        'canonical_name': 'str',
        'data_type': 'str',
        'multiple_values_data_type': 'bool',
        'name': 'str',
        'property_set': 'str'
    }

    attribute_map = {
        'discriminator': 'discriminator',
        'canonical_name': 'canonicalName',
        'data_type': 'dataType',
        'multiple_values_data_type': 'multipleValuesDataType',
        'name': 'name',
        'property_set': 'propertySet'
    }

    def __init__(self, canonical_name: str = None, data_type: str = None, multiple_values_data_type: bool = None, name: str = None, property_set: str = None):
        """
        Property identified by a string name along with a property set             
        :param canonical_name: The name used to refer to the property in the documentation. The prefix of the canonical name identifies the basic characteristics of a property to the implementer. The canonical naming structure uses three categories that are denoted by the following prefixes to the canonical property name: * PidLid prefix: Properties identified by an unsigned 32-bit quantity along with a property set. * PidName prefix: Properties identified by a string name along with a property set. * PidTag prefix: Properties identified by an unsigned 16-bit quantity.             
        :type canonical_name: str
        :param data_type: [MS-OXCDATA]: Data Structures Enum, available values: Unspecified, Null, Integer16, Integer32, Floating32, Floating64, Currency, FloatingTime, ErrorCode, Boolean, Integer64, String, String8, Time, Guid, ServerId, Restriction, RuleAction, Binary, MultipleInteger16, MultipleInteger32, MultipleFloating32, MultipleFloating64, MultipleCurrency, MultipleFloatingTime, MultipleBoolean, MultipleInteger64, MultipleString, MultipleString8, MultipleTime, MultipleGuid, MultipleBinary, Object
        :type data_type: str
        :param multiple_values_data_type: Indicates if data type contains of multiple values             
        :type multiple_values_data_type: bool
        :param name: A string that identifies the property             
        :type name: str
        :param property_set: A GUID that identifies a group of properties with a similar purpose.             
        :type property_set: str
        """
        super(MapiPidNamePropertyDescriptor, self).__init__()

        self._property_set = None
        if canonical_name is not None:
            self.canonical_name = canonical_name
        if data_type is not None:
            self.data_type = data_type
        if multiple_values_data_type is not None:
            self.multiple_values_data_type = multiple_values_data_type
        if name is not None:
            self.name = name
        if property_set is not None:
            self.property_set = property_set


    @property
    def property_set(self) -> str:
        """
        A GUID that identifies a group of properties with a similar purpose.             

        :return: The property_set of this MapiPidNamePropertyDescriptor.
        :rtype: str
        """
        return self._property_set

    @property_set.setter
    def property_set(self, property_set: str):
        """
        A GUID that identifies a group of properties with a similar purpose.             

        :param property_set: The property_set of this MapiPidNamePropertyDescriptor.
        :type: str
        """
        if property_set is None:
            raise ValueError("Invalid value for `property_set`, must not be `None`")
        self._property_set = property_set

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiPidNamePropertyDescriptor):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MonthlyRecurrencePatternDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.recurrence_pattern_dto import RecurrencePatternDto


class MonthlyRecurrencePatternDto(RecurrencePatternDto):
    """Monthly recurrence pattern.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'interval': 'int',
        'occurs': 'int',
        'end_date': 'datetime',
        'week_start': 'str',
        'discriminator': 'str',
        'start_day': 'str',
        'start_offset': 'int',
        'start_position': 'str'
    }

    attribute_map = {
        'interval': 'interval',
        'occurs': 'occurs',
        'end_date': 'endDate',
        'week_start': 'weekStart',
        'discriminator': 'discriminator',
        'start_day': 'startDay',
        'start_offset': 'startOffset',
        'start_position': 'startPosition'
    }

    def __init__(self, interval: int = None, occurs: int = None, end_date: datetime = None, week_start: str = None, start_day: str = None, start_offset: int = None, start_position: str = None):
        """
        Monthly recurrence pattern.             
        :param interval: Number of recurrence units.             
        :type interval: int
        :param occurs: Number of occurrences of the recurrence pattern.             
        :type occurs: int
        :param end_date: End date.             
        :type end_date: datetime
        :param week_start: Represents the day of the week. Enum, available values: None, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday, Day, WeekDay, WeekendDay
        :type week_start: str
        :param start_day: Represents the day of the week. Enum, available values: None, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday, Day, WeekDay, WeekendDay
        :type start_day: str
        :param start_offset: Start offset.             
        :type start_offset: int
        :param start_position: Day positions, typically found in a month. Enum, available values: None, First, Second, Third, Fourth, Last
        :type start_position: str
        """
        super(MonthlyRecurrencePatternDto, self).__init__()

        self._start_day = None
        self._start_offset = None
        self._start_position = None

        if interval is not None:
            self.interval = interval
        if occurs is not None:
            self.occurs = occurs
        if end_date is not None:
            self.end_date = end_date
        if week_start is not None:
            self.week_start = week_start
        if start_day is not None:
            self.start_day = start_day
        if start_offset is not None:
            self.start_offset = start_offset
        if start_position is not None:
            self.start_position = start_position


    @property
    def start_day(self) -> str:
        """
        Represents the day of the week. Enum, available values: None, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday, Day, WeekDay, WeekendDay

        :return: The start_day of this MonthlyRecurrencePatternDto.
        :rtype: str
        """
        return self._start_day

    @start_day.setter
    def start_day(self, start_day: str):
        """
        Represents the day of the week. Enum, available values: None, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday, Day, WeekDay, WeekendDay

        :param start_day: The start_day of this MonthlyRecurrencePatternDto.
        :type: str
        """
        if start_day is None:
            raise ValueError("Invalid value for `start_day`, must not be `None`")
        self._start_day = start_day

    @property
    def start_offset(self) -> int:
        """
        Start offset.             

        :return: The start_offset of this MonthlyRecurrencePatternDto.
        :rtype: int
        """
        return self._start_offset

    @start_offset.setter
    def start_offset(self, start_offset: int):
        """
        Start offset.             

        :param start_offset: The start_offset of this MonthlyRecurrencePatternDto.
        :type: int
        """
        if start_offset is None:
            raise ValueError("Invalid value for `start_offset`, must not be `None`")
        self._start_offset = start_offset

    @property
    def start_position(self) -> str:
        """
        Day positions, typically found in a month. Enum, available values: None, First, Second, Third, Fourth, Last

        :return: The start_position of this MonthlyRecurrencePatternDto.
        :rtype: str
        """
        return self._start_position

    @start_position.setter
    def start_position(self, start_position: str):
        """
        Day positions, typically found in a month. Enum, available values: None, First, Second, Third, Fourth, Last

        :param start_position: The start_position of this MonthlyRecurrencePatternDto.
        :type: str
        """
        if start_position is None:
            raise ValueError("Invalid value for `start_position`, must not be `None`")
        self._start_position = start_position

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MonthlyRecurrencePatternDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
